//---------------------------------------------------------------------------
// File: TMainForm.cpp, TDx_Draw_Library v1.4, Example4 - Cooperative Levels
//
// Date: 6th March, 2001
// Author: Darren John Dwyer
// Copyright: (c) 2001 Darren John Dwyer, All Rights Reserved.
//
// Description:
//
// This example shows how to set and retrieve the cooperative level for a
// given device using the TDx_Draw::SetCooperativeLevel() and
// TDx_Draw::TestCooperativeLevel() methods.
//
// NOTE: When setting the cooperative level, DirectX states that you should
// supply the top-most window handle for the entire application, hence
// the use of Application->Handle instead of MainForm->Handle.
//
//---------------------------------------------------------------------------
#include <vcl\vcl.h>
#pragma hdrstop
//---------------------------------------------------------------------------
#include "TMainForm.h"
//---------------------------------------------------------------------------
#if (__BORLANDC__ >= 0x0530) // BCB Version 3 +
    #pragma package(smart_init)
#endif
//---------------------------------------------------------------------------
#pragma resource "*.dfm"
//---------------------------------------------------------------------------
#pragma link "TDx_Draw"
#pragma link "TDx_DrawSurface"
#pragma link "TDDCaps"
#pragma link "TDDPixelFormat"
#pragma link "TDDSCaps"
#pragma link "TDDSurfaceDesc"
#pragma link "TDx_Draw_Library_Install"
//---------------------------------------------------------------------------
TMainForm *MainForm;
//---------------------------------------------------------------------------
AnsiString IntToHexStr( unsigned int hexvalue )
{
char* hexchars[16] = {"0","1","2","3","4","5","6","7","8","9","A","B","C","D","E","F"};
AnsiString string = "0x";
int value = 0x10000000;
for (int i=0;i<8;i++)
    {
    string += hexchars[hexvalue/value];
    hexvalue -= value * (hexvalue/value);
    value = value >> 4;
    }
return string;
}
//---------------------------------------------------------------------------
#define Msg(A)  {\
                if (StatusMemo->Text.Length()>30000) StatusMemo->Text = "";\
                StatusMemo->Lines->Add(A);\
                }
//---------------------------------------------------------------------------
__fastcall TMainForm::TMainForm(TComponent* Owner)
    : TForm(Owner)
{
}
//---------------------------------------------------------------------------
__fastcall TMainForm::~TMainForm()
{
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::FormCreate(TObject *Sender)
{
Width=780;
Height=580;
Position=poScreenCenter;
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::FormDestroy(TObject *Sender)
{
if (Dx_Draw1->Created) Dx_Draw1->Destroy();
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::CreateDefaultButtonClick(TObject *Sender)
{
Msg("Creating Default Device");
Dx_Draw1->Create(NULL);
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::FullscreenButtonClick(TObject *Sender)
{
Msg("Setting Fullscreen/Exclusive Mode");
if (Dx_Draw1->SetCooperativeLevel( Application->Handle, DDSCL_FULLSCREEN | DDSCL_EXCLUSIVE ))
    Msg("Fullscreen/Exclusive Mode has been set");
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::TestFullscreenButtonClick(TObject *Sender)
{
HRESULT level = Dx_Draw1->TestCooperativeLevel();
AnsiString caption = "Coop Level: " + IntToHexStr(level) + "\n";
if (level == DD_OK) caption = caption + "Cooperative Level is DD_OK\n";
else
    {
    caption = caption + "Cooperative Level is not DD_OK\n";
    if (level == DDERR_WRONGMODE) caption = caption + "Wrong Mode\n";
    if (level == DDERR_INVALIDOBJECT) caption = caption + "Invalid Object\n";
    if (level == DDERR_NOEXCLUSIVEMODE) caption = caption + "No Exclusive Mode\n";
    if (level == DDERR_EXCLUSIVEMODEALREADYSET) caption = caption + "Exclusive Mode Already Set\n";
    }
CurrentCoopLevelLabel->Caption = caption;
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::NormalModeButtonClick(TObject *Sender)
{
Msg("Setting Normal Mode");
if (Dx_Draw1->SetCooperativeLevel( Application->Handle, DDSCL_NORMAL ))
    Msg("Normal Mode has been set");
}
//---------------------------------------------------------------------------

void __fastcall TMainForm::DestroyDefaultButtonClick(TObject *Sender)
{
Msg("Destroying Default Device");
Dx_Draw1->Destroy();
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::ExitButtonClick(TObject *Sender)
{
Close();
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::ClearButtonClick(TObject *Sender)
{
StatusMemo->Lines->Clear();
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::Dx_Draw1Create(TObject *Sender)
{
Msg("Device Created: 'Default DirectDraw Device'");
ActiveDeviceLabel->Caption = "-- Default --";
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::Dx_Draw1Destroy(TObject *Sender)
{
Msg("Device Destroyed: 'Default DirectDraw Device'");
ActiveDeviceLabel->Caption = "-- none --";
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::Dx_Draw1Error(TObject *Sender, AnsiString Function,
    AnsiString Error, AnsiString ErrorMessage)
{
Msg("ERROR ["+Error+"]: "+Function+", "+ErrorMessage);
}
//---------------------------------------------------------------------------


